diff src/fileio.c @ 16694:ed9b15758241 v8.1.1349

patch 8.1.1349: if writing runs into conversion error backup file is deleted commit https://github.com/vim/vim/commit/cf0bfd9ade5173bcc12563bfc90c21a4db10535d Author: Bram Moolenaar <Bram@vim.org> Date: Sat May 18 18:52:04 2019 +0200 patch 8.1.1349: if writing runs into conversion error backup file is deleted Problem: If writing runs into a conversion error the backup file is deleted. (Arseny Nasokin) Solution: Don't delete the backup file is the file was overwritten and a conversion error occurred. (Christian Brabandt, closes #4387)
author Bram Moolenaar <Bram@vim.org>
date Sat, 18 May 2019 19:00:05 +0200
parents 4e9bea9b8025
children e42e9fa83e60
line wrap: on
line diff
--- a/src/fileio.c
+++ b/src/fileio.c
@@ -4985,10 +4985,10 @@ restore_backup:
 	}
     }
 
-    /*
-     * Remove the backup unless 'backup' option is set
-     */
-    if (!p_bk && backup != NULL && mch_remove(backup) != 0)
+    // Remove the backup unless 'backup' option is set or there was a
+    // conversion error.
+    if (!p_bk && backup != NULL && !write_info.bw_conv_error
+	    && mch_remove(backup) != 0)
 	emsg(_("E207: Can't delete backup file"));
 
     goto nofail;